from setuptools import setup

setup(name='mergesitemap',
      version='0.2',
      description='Combines XML site maps',
      url='http://github.com/kindlyops/mergesitemap',
      author='Kindly Ops LLC',
      author_email='support@kindlyops.com',
      license='Apache2',
      scripts=['bin/mergesitemap'],
      zip_safe=False)
